'''
This tool can be used to run setup.py inplace.

Not currently using this (using pyximport instead), but it's here for debugging because pyximport does not give us
access to the c file.
'''

import os
os.system('python setup.py build_ext --inplace')



import nose
import os
import klustakwik2

__all__ = ['run']

def run():
    klustakwik2.console_log_level('critical')
    dirname = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
    nose.run(argv=['', dirname,
                   '-c=',  # no config file loading
                   '-I', '^\.',
                   '-I', '^_',
                   '--logging-clear-handlers',
                    '--nologcapture',
#                    '--exe',
                   ])
        


'''
Not currently using this (using pyximport instead), but it's here for debugging because pyximport does not give us
access to the c file.
'''

from distutils.core import setup
from Cython.Build import cythonize
import numpy

setup(
    ext_modules=cythonize("compute_cluster_masks.pyx"),
    include_dirs=[numpy.get_include()]
)



import numpy as _numpy
import pyximport as _pyximport
 
_pyximport.install(setup_args={'include_dirs':_numpy.get_include()})

from .compute_cluster_masks import *
from .e_step import *
from .m_step import *
from .masks import *
